@@ -1,4 +1,4 @@
-use azure_storage::core::{ConnectionStringBuilder, EndpointProtocol};
+use azure_storage::{ConnectionStringBuilder, EndpointProtocol};
 
 pub fn main() {
     let account_name =
@@ -18,5 +18,5 @@ pub fn main() {
         .default_endpoints_protocol(default_endpoints_protocol)
         .build();
 
-    println!("The connection string is: '{}'", connection_string);
+    println!("The connection string is: '{connection_string}'");
 }
