@@ -1,5 +1,4 @@
-use azure_storage::core::prelude::*;
-use azure_storage_blobs::blob::responses::GetBlobResponse;
+use azure_storage::StorageCredentials;
 use azure_storage_blobs::prelude::*;
 use futures::stream::StreamExt;
 
@@ -10,39 +9,27 @@ use futures::stream::StreamExt;
 // We do not use leases here but you definitely want to do so otherwise the returned stream
 // is not guaranteed to be consistent.
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+async fn main() -> azure_core::Result<()> {
     let file_name = "azure_sdk_for_rust_stream_test.txt";
 
-    // First we retrieve the account name and master key from environment variables.
+    // First we retrieve the account name and access key from environment variables.
     let account =
         std::env::var("STORAGE_ACCOUNT").expect("Set env variable STORAGE_ACCOUNT first!");
-    let master_key =
-        std::env::var("STORAGE_MASTER_KEY").expect("Set env variable STORAGE_MASTER_KEY first!");
+    let access_key =
+        std::env::var("STORAGE_ACCESS_KEY").expect("Set env variable STORAGE_ACCESS_KEY first!");
 
     let container_name = std::env::args()
         .nth(1)
         .expect("please specify container name as first command line parameter");
 
-    let http_client = azure_core::new_http_client();
-
+    let storage_credentials = StorageCredentials::access_key(account.clone(), access_key);
     let blob_client =
-        StorageAccountClient::new_access_key(http_client.clone(), &account, &master_key)
-            .as_container_client(&container_name)
-            .as_blob_client(file_name);
-
-    let mut stream = Box::pin(get_blob_stream(&blob_client));
+        ClientBuilder::new(account, storage_credentials).blob_client(container_name, file_name);
 
+    let mut stream = blob_client.get().into_stream();
     while let Some(res) = stream.next().await {
         println!("{:?}", res.unwrap());
     }
 
     Ok(())
 }
-
-fn get_blob_stream(
-    blob_client: &'_ BlobClient,
-) -> impl futures::Stream<Item = Result<GetBlobResponse, Box<dyn std::error::Error + Send + Sync>>> + '_
-{
-    let stream = blob_client.get().stream(1024);
-    stream
-}
